@@ -16,11 +16,11 @@ from datetime import datetime
 from typing import IO, Dict, List, Union
 
 from .literals import (
-    ClientBroker,
-    ClusterState,
-    ConfigurationState,
-    EnhancedMonitoring,
-    KafkaVersionStatus,
+    ClientBrokerType,
+    ClusterStateType,
+    ConfigurationStateType,
+    EnhancedMonitoringType,
+    KafkaVersionStatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -230,11 +230,11 @@ ClusterInfoTypeDef = TypedDict(
         "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
         "CurrentVersion": str,
         "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": EnhancedMonitoring,
+        "EnhancedMonitoring": EnhancedMonitoringType,
         "OpenMonitoring": "OpenMonitoringTypeDef",
         "LoggingInfo": "LoggingInfoTypeDef",
         "NumberOfBrokerNodes": int,
-        "State": ClusterState,
+        "State": ClusterStateType,
         "StateInfo": "StateInfoTypeDef",
         "Tags": Dict[str, str],
         "ZookeeperConnectString": str,
@@ -326,7 +326,7 @@ ConfigurationTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": ConfigurationState,
+        "State": ConfigurationStateType,
     },
 )
 
@@ -335,7 +335,7 @@ CreateClusterResponseTypeDef = TypedDict(
     {
         "ClusterArn": str,
         "ClusterName": str,
-        "State": ClusterState,
+        "State": ClusterStateType,
     },
     total=False,
 )
@@ -347,7 +347,7 @@ CreateConfigurationResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": ConfigurationState,
+        "State": ConfigurationStateType,
     },
     total=False,
 )
@@ -356,7 +356,7 @@ DeleteClusterResponseTypeDef = TypedDict(
     "DeleteClusterResponseTypeDef",
     {
         "ClusterArn": str,
-        "State": ClusterState,
+        "State": ClusterStateType,
     },
     total=False,
 )
@@ -365,7 +365,7 @@ DeleteConfigurationResponseTypeDef = TypedDict(
     "DeleteConfigurationResponseTypeDef",
     {
         "Arn": str,
-        "State": ConfigurationState,
+        "State": ConfigurationStateType,
     },
     total=False,
 )
@@ -395,7 +395,7 @@ DescribeConfigurationResponseTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
-        "State": ConfigurationState,
+        "State": ConfigurationStateType,
     },
     total=False,
 )
@@ -430,7 +430,7 @@ EncryptionAtRestTypeDef = TypedDict(
 EncryptionInTransitTypeDef = TypedDict(
     "EncryptionInTransitTypeDef",
     {
-        "ClientBroker": ClientBroker,
+        "ClientBroker": ClientBrokerType,
         "InCluster": bool,
     },
     total=False,
@@ -518,7 +518,7 @@ KafkaVersionTypeDef = TypedDict(
     "KafkaVersionTypeDef",
     {
         "Version": str,
-        "Status": KafkaVersionStatus,
+        "Status": KafkaVersionStatusType,
     },
     total=False,
 )
@@ -607,7 +607,7 @@ MutableClusterInfoTypeDef = TypedDict(
         "BrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
         "ConfigurationInfo": "ConfigurationInfoTypeDef",
         "NumberOfBrokerNodes": int,
-        "EnhancedMonitoring": EnhancedMonitoring,
+        "EnhancedMonitoring": EnhancedMonitoringType,
         "OpenMonitoring": "OpenMonitoringTypeDef",
         "KafkaVersion": str,
         "LoggingInfo": "LoggingInfoTypeDef",
